# HybridSuperQubits

[![PyPI Version](https://img.shields.io/pypi/v/HybridSuperQubits)](https://pypi.org/project/HybridSuperQubits/)
[![License](https://img.shields.io/badge/License-MIT-blue)](LICENSE)

Package for hybrid simulation of superconducting qubits.

## Installation
```bash
pip install HybridSuperQubits
```

## Usage
```python
from HybridSuperQubits.ferbo import Ferbo
ferbo = Ferbo(...)
```

## License
This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
